Module direct

Type aliases for DirectIdMap

Type Aliases

DirectIdMap
An IdMap that stores its entries without any indirection, but takes much more space when entries are missing.
Entry
An entry in an DirectIdMap
Iter
An iterator over the entries of an DirectIdMap
IterMut
An mutable iterator over the entries of an DirectIdMap
Keys
An iterator over the keys of an DirectIdMap
OccupiedEntry
An occupied entry in an DirectIdMap
VacantEntry
A vacant entry in an DirectIdMap
Values
An iterator over the values of an DirectIdMap
ValuesMut
An mutable iterator over the values of an DirectIdMap