Module map

Module map 

Implements DirectIdMap, a thin wrapper over a Vec<Option<T>>.

Structs

DirectIdMap
A map implemented as a Vec<Option<T>>, which takes space proportional to the size of the maximum id.
IntoIter
An iterator consuming the entries in a DirectIdMap/
Iter
An iterator over the entries in a DirectIdMap.
IterMut
A mutable iterator over the entries in a DirectIdMap.
Keys
A iterator over the keys in a DirectIdMap.
Values
A iterator over the values in a DirectIdMap.
ValuesMut
A mutable iterator over the values in a DirectIdMap.