pub struct DirectIdMap<K: IntegerId, V> { /* private fields */ }Expand description
A map implemented as a Vec<Option<T>>,
which takes space proportional to the size of the maximum id.
There is no entry API because the overhead of lookups is very small.
Implementations
Sourceimpl<K: IntegerId, V> DirectIdMap<K, V>
impl<K: IntegerId, V> DirectIdMap<K, V>
Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
Trim unused capacity.
Sourcepub fn contains_key(&self, id: impl EquivalentId<K>) -> bool
pub fn contains_key(&self, id: impl EquivalentId<K>) -> bool
Check if the specified key is present in the map.
Sourcepub fn get(&self, id: impl EquivalentId<K>) -> Option<&V>
pub fn get(&self, id: impl EquivalentId<K>) -> Option<&V>
Get the value associated with the specified key, or None if missing.
Sourcepub fn get_mut(&mut self, id: impl EquivalentId<K>) -> Option<&mut V>
pub fn get_mut(&mut self, id: impl EquivalentId<K>) -> Option<&mut V>
Get a mutable reference to the value associated with the specified key,
or None if missing.
Sourcepub fn insert(&mut self, id: K, value: V) -> Option<V>
pub fn insert(&mut self, id: K, value: V) -> Option<V>
Insert a key and a value, returning the previous value.
Sourcepub fn remove(&mut self, id: impl EquivalentId<K>) -> Option<V>
pub fn remove(&mut self, id: impl EquivalentId<K>) -> Option<V>
Remove a value associated with the given, returning the previous value ifp resent.
Sourcepub fn iter(&self) -> Iter<'_, K, V> ⓘ
pub fn iter(&self) -> Iter<'_, K, V> ⓘ
Iterate over the key-value pairs in the map.
Guaranteed to be sorted by the integer id of the key.