DirectIdSet

Struct DirectIdSet 

pub struct DirectIdSet<T: IntegerId> { /* private fields */ }
A set whose members implement IntegerId.

This is implemented as a bitset, so memory is proportional to the highest integer index.

Implementations

Source

impl<T: IntegerId> DirectIdSet<T>

pub const fn new() -> Self

Create a new DirectIdSet with no elements.

pub fn with_capacity(max_id: usize) -> Self

Initialize the set with the given capacity

Since this is a direct set, this hints at the maximum valid id and not the length.

pub fn insert(&mut self, value: T) -> bool

Inserts the specified element into the set, returning true if it was already in the set and false if it wasn’t.

pub fn remove(&mut self, value: impl EquivalentId<T>) -> bool

Remove the specified value from the set, returning whether it was previously present.

pub fn contains(&self, value: impl EquivalentId<T>) -> bool

Check if this set contains the specified value

pub fn iter(&self) -> Iter<'_, T>

Iterate over the values in this set.

Guaranteed to be ordered by the integer value of the key.

pub fn clear(&mut self)

Clear the values in this set

pub fn len(&self) -> usize

The number of entries in this set

An DirectIdSet internally tracks this length, so this is a O(1) operation

pub fn is_empty(&self) -> bool

If this set is empty

pub fn retain<F: FnMut(T) -> bool>(&mut self, func: F)

Retain values in the set if the specified closure returns true

Otherwise, they are removed