pub type IterMut<'a, K, V> = IterMut<'a, K, V, DirectEntryTable<K, V>>;Expand description
An mutable iterator over the entries of an DirectIdMap
Aliased Type
pub struct IterMut<'a, K, V>(/* private fields */);pub type IterMut<'a, K, V> = IterMut<'a, K, V, DirectEntryTable<K, V>>;An mutable iterator over the entries of an DirectIdMap
pub struct IterMut<'a, K, V>(/* private fields */);