pub type ValuesMut<'a, K, V> = ValuesMut<'a, K, V, DirectEntryTable<K, V>>;Expand description
An mutable iterator over the values of an DirectIdMap
Aliased Type
pub struct ValuesMut<'a, K, V>(/* private fields */);pub type ValuesMut<'a, K, V> = ValuesMut<'a, K, V, DirectEntryTable<K, V>>;An mutable iterator over the values of an DirectIdMap
pub struct ValuesMut<'a, K, V>(/* private fields */);