Struct DirectEntryTable

pub struct DirectEntryTable<K: IntegerId, V> { /* private fields */ }
A entry table that stores in a flat array

This has very fast O(1) access but can waste memory if the entries are sparse