pub struct DirectIdSet<T: IntegerId> { /* private fields */ }Expand description
A set whose members implement IntegerId.
This is implemented as a bitset, so memory is proportional to the highest integer index.
Implementations
Sourceimpl<T: IntegerId> DirectIdSet<T>
impl<T: IntegerId> DirectIdSet<T>
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Create a new DirectIdSet with no elements.
Sourcepub fn with_capacity(max_id: usize) -> Self
pub fn with_capacity(max_id: usize) -> Self
Initialize the set with the given capacity
Since this is a direct set, this hints at the maximum valid id and not the length.
Sourcepub fn insert(&mut self, value: T) -> bool
pub fn insert(&mut self, value: T) -> bool
Inserts the specified element into the set,
returning true if it was already in the set and false if it wasn’t.
Sourcepub fn remove(&mut self, value: impl EquivalentId<T>) -> bool
pub fn remove(&mut self, value: impl EquivalentId<T>) -> bool
Remove the specified value from the set, returning whether it was previously present.
Sourcepub fn contains(&self, value: impl EquivalentId<T>) -> bool
pub fn contains(&self, value: impl EquivalentId<T>) -> bool
Check if this set contains the specified value
Sourcepub fn iter(&self) -> Iter<'_, T> ⓘ
pub fn iter(&self) -> Iter<'_, T> ⓘ
Iterate over the values in this set.
Guaranteed to be ordered by the integer value of the key.
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
The number of entries in this set
An DirectIdSet internally tracks this length, so this is a O(1) operation