pub struct EnumMap<K: EnumId, V> { /* private fields */ }Expand description
A map from an EnumId key to values,
implemented using an inline array.
This is similar to a EnumMap and is also “direct”,
although that is omitted from the name for conciseness.
Implementing the EnumId trait implies that the ids are relatively compact,
although this is not a strict requirement.
There is no entry API because the overhead of lookups is very small.
Implementations
Sourceimpl<K: EnumId, V> EnumMap<K, V>
impl<K: EnumId, V> EnumMap<K, V>
Sourcepub fn new_boxed() -> Box<Self>
pub fn new_boxed() -> Box<Self>
Create a new map with no entries, allocating memory on the heap instead of the stack.
Using Box::new(EnumMapDirect::new()) could require moving the underlying table
from the stack to the heap, as LLVM can struggle at eliminating copies.
This method avoids that copy by always allocating in-place.
Sourcepub fn contains_key(&self, id: impl EquivalentId<K>) -> bool
pub fn contains_key(&self, id: impl EquivalentId<K>) -> bool
Check if the specified key is present in the map.
Sourcepub fn get(&self, id: impl EquivalentId<K>) -> Option<&V>
pub fn get(&self, id: impl EquivalentId<K>) -> Option<&V>
Get the value associated with the specified key, or None if missing.
Sourcepub fn get_mut(&mut self, id: impl EquivalentId<K>) -> Option<&mut V>
pub fn get_mut(&mut self, id: impl EquivalentId<K>) -> Option<&mut V>
Get a mutable reference to the value associated with the specified key,
or None if missing.
Sourcepub fn insert(&mut self, id: K, value: V) -> Option<V>
pub fn insert(&mut self, id: K, value: V) -> Option<V>
Insert a key and a value, returning the previous value.
Sourcepub fn remove(&mut self, id: impl EquivalentId<K>) -> Option<V>
pub fn remove(&mut self, id: impl EquivalentId<K>) -> Option<V>
Remove a value associated with the given, returning the previous value ifp resent.
Sourcepub fn iter(&self) -> Iter<'_, K, V> ⓘ
pub fn iter(&self) -> Iter<'_, K, V> ⓘ
Iterate over the key-value pairs in the map.
Guaranteed to be sorted by the integer id of the key.