[−][src]Trait idmap::table::EntryIterable
Allows iteration over pointers to all a table's valid entries.
This trait is completely unsafe and has to use raw pointers, since there's currently no way for a trait to express that the iterators it returns are bound to the lifetime of the struct.
Using the either the iterator or the values it return beyond the lifetime of the reference to
the iterable is undefined behavior the compiler can't check your for,
so it's recommended to use the safe wrappers SafeEntries and SafeEntriesMut
However, it can be safely wrapped in SafeEntries and SafeEntriesMut traits.